# Copyright (C) 2021 MicroSys Electronics GmbH, Author Kay Potthoff
# Author: Kay Potthoff <kay.potthoff@microsys.de>

FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"
PATCH_COMMIT_FUNCTIONS = "1"

#BRANCH = "release/bsp32.0-2.5"
#SRCREV = "b6b0419ec2d8cf84d1bf17cb3cd13d16558d639f"

PROVIDES += "virtual/arm-trusted-firmware"

inherit deploy

PACKAGE_ARCH = "${MACHINE_ARCH}"

do_compile[depends] = "u-boot-s32:do_install"

python do_patch_prepend() {
    if d.getVar('PATCHTOOL') == 'git':
        srcsubdir = d.getVar('S')
        bb.process.run('git config am.threeWay true', cwd=srcsubdir)
        bb.process.run('git config am.keepcr true', cwd=srcsubdir)
        bb.process.run('git config apply.whitespace fix', cwd=srcsubdir)
        bb.process.run('git config apply.ignoreWhitespace change', cwd=srcsubdir)
}

PLATFORM_s32g2 = "mpxs32g274a"
COMPATIBLE_MACHINE .= "|(mpxs32g274a)"

# The package is empty which leads to problems when
# building the image with devtool. This fix lets devtool
# build the image with modified arm-trusted-firmware.
ALLOW_EMPTY_${PN} = "1"

# Set log-level:
#       0  (LOG_LEVEL_NONE)
#       10 (LOG_LEVEL_ERROR)
#       20 (LOG_LEVEL_NOTICE)
#       30 (LOG_LEVEL_WARNING)
#       40 (LOG_LEVEL_INFO)
#       50 (LOG_LEVEL_VERBOSE)
# Default is LOG_LEVEL_INFO (40):
#EXTRA_OEMAKE += "LOG_LEVEL=40"

# Uncomment these lines for more debugging:
#BUILD_TYPE = "debug"
#EXTRA_OEMAKE += "S32G_USE_LINFLEX_IN_BL31=1 DEBUG=1"

do_compile_prepend() {
	BUILD_STRING=`cat ${S}/localversion-microsys`
	export BUILD_STRING
}

SRC_URI += "file://0001-mpxs32g274a-added-platform.patch;name=patch0001"
SRC_URI += "file://0002-mpxs32g274a-fixed-missing-platform_def.h.patch;name=patch0002"
SRC_URI += "file://0003-localversion-5.0.5.patch;name=patch0003"
SRC_URI += "file://0004-drivers-mmc-increased-retries.patch;name=patch0004"
SRC_URI += "file://0005-drivers-nxp-s32-mmc-wait-for-stable-clock.patch;name=patch0005"
SRC_URI += "file://0006-drivers-nxp-s32-mmc-reduced-max.-speed.patch;name=patch0006"
SRC_URI += "file://0007-Revert-drivers-mmc-increased-retries.patch;name=patch0007"
SRC_URI += "file://0008-mpxs32g274arev3-added-platform.patch;name=patch0008"
SRC_URI += "file://0009-localversion-5.0.6.patch;name=patch0009"
SRC_URI += "file://0010-drivers-nxp-s32-s32_i2c.c.patch;name=patch0010"

SRC_URI[patch0001.md5sum] = "e85e091bc220830ae51ebd09a6320e32"
SRC_URI[patch0002.md5sum] = "a400f20aa9fa7ac3da65892a04b12642"
SRC_URI[patch0003.md5sum] = "3efc8c0bf9a56f459de005446f81e841"
SRC_URI[patch0004.md5sum] = "b32fd71aecf16011a7e74ff1f444e640"
SRC_URI[patch0005.md5sum] = "470e0cd56ea9da645db56090dc2aed69"
SRC_URI[patch0006.md5sum] = "77e294719d17c915b7933bbdb25debdc"
SRC_URI[patch0007.md5sum] = "a3b742a994081c22e0fd71102d52c227"
SRC_URI[patch0008.md5sum] = "cae3ee26c9624ba65675b544100a3482"
SRC_URI[patch0009.md5sum] = "4cd272f94fcf54ea001b758e35bae0fb"
SRC_URI[patch0010.md5sum] = "be442a4a70c53ab9839707a1ef3328a4"
